soakdb3
=======================================================================

XChem replacement for soakdb2, including a new database backend.

..
    Anything below this line is used when viewing README.rst and will be replaced
    when included in index.rst



Documentation
-----------------------------------------------------------------------

See https://diamondlightsource.github.io/soakdb3 for more detailed documentation.

